tiled.client.dataframe.DaskDataFrameClient.read\_partition
==========================================================

.. currentmodule:: tiled.client.dataframe

.. automethod:: DaskDataFrameClient.read_partition